package
Version:
v0.0.0-...-13c0080
Opens a new window with list of versions in this module.
Published: Jul 30, 2024
License: Unlicense
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (s *Set[T]) Add(value T)
func (s *Set[T]) Contains(value T) bool
func (s *Set[T]) Remove(value T)
func (s *Set[T]) Values() []T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.